#define KEY_NULL		0
#define KEY___FILE__		1
#define KEY___LINE__		2
#define KEY___PACKAGE__		3
#define KEY___DATA__		4
#define KEY___END__		5
#define KEY_AUTOLOAD		6
#define KEY_BEGIN		7
#define KEY_CORE		8
#define KEY_DESTROY		9
#define KEY_END			10
#define KEY_EQ			11
#define KEY_GE			12
#define KEY_GT			13
#define KEY_INIT		14
#define KEY_LE			15
#define KEY_LT			16
#define KEY_NE			17
#define KEY_abs			18
#define KEY_accept		19
#define KEY_alarm		20
#define KEY_and			21
#define KEY_atan2		22
#define KEY_bind		23
#define KEY_binmode		24
#define KEY_bless		25
#define KEY_caller		26
#define KEY_chdir		27
#define KEY_chmod		28
#define KEY_chomp		29
#define KEY_chop		30
#define KEY_chown		31
#define KEY_chr			32
#define KEY_chroot		33
#define KEY_close		34
#define KEY_closedir		35
#define KEY_cmp			36
#define KEY_connect		37
#define KEY_continue		38
#define KEY_cos			39
#define KEY_crypt		40
#define KEY_dbmclose		41
#define KEY_dbmopen		42
#define KEY_defined		43
#define KEY_delete		44
#define KEY_die			45
#define KEY_do			46
#define KEY_dump		47
#define KEY_each		48
#define KEY_else		49
#define KEY_elsif		50
#define KEY_endgrent		51
#define KEY_endhostent		52
#define KEY_endnetent		53
#define KEY_endprotoent		54
#define KEY_endpwent		55
#define KEY_endservent		56
#define KEY_eof			57
#define KEY_eq			58
#define KEY_eval		59
#define KEY_exec		60
#define KEY_exists		61
#define KEY_exit		62
#define KEY_exp			63
#define KEY_fcntl		64
#define KEY_fileno		65
#define KEY_flock		66
#define KEY_for			67
#define KEY_foreach		68
#define KEY_fork		69
#define KEY_format		70
#define KEY_formline		71
#define KEY_ge			72
#define KEY_getc		73
#define KEY_getgrent		74
#define KEY_getgrgid		75
#define KEY_getgrnam		76
#define KEY_gethostbyaddr	77
#define KEY_gethostbyname	78
#define KEY_gethostent		79
#define KEY_getlogin		80
#define KEY_getnetbyaddr	81
#define KEY_getnetbyname	82
#define KEY_getnetent		83
#define KEY_getpeername		84
#define KEY_getpgrp		85
#define KEY_getppid		86
#define KEY_getpriority		87
#define KEY_getprotobyname	88
#define KEY_getprotobynumber	89
#define KEY_getprotoent		90
#define KEY_getpwent		91
#define KEY_getpwnam		92
#define KEY_getpwuid		93
#define KEY_getservbyname	94
#define KEY_getservbyport	95
#define KEY_getservent		96
#define KEY_getsockname		97
#define KEY_getsockopt		98
#define KEY_glob		99
#define KEY_gmtime		100
#define KEY_goto		101
#define KEY_grep		102
#define KEY_gt			103
#define KEY_hex			104
#define KEY_if			105
#define KEY_index		106
#define KEY_int			107
#define KEY_ioctl		108
#define KEY_join		109
#define KEY_keys		110
#define KEY_kill		111
#define KEY_last		112
#define KEY_lc			113
#define KEY_lcfirst		114
#define KEY_le			115
#define KEY_length		116
#define KEY_link		117
#define KEY_listen		118
#define KEY_local		119
#define KEY_localtime		120
#define KEY_lock		121
#define KEY_log			122
#define KEY_lstat		123
#define KEY_lt			124
#define KEY_m			125
#define KEY_map			126
#define KEY_mkdir		127
#define KEY_msgctl		128
#define KEY_msgget		129
#define KEY_msgrcv		130
#define KEY_msgsnd		131
#define KEY_my			132
#define KEY_ne			133
#define KEY_next		134
#define KEY_no			135
#define KEY_not			136
#define KEY_oct			137
#define KEY_open		138
#define KEY_opendir		139
#define KEY_or			140
#define KEY_ord			141
#define KEY_our			142
#define KEY_pack		143
#define KEY_package		144
#define KEY_pipe		145
#define KEY_pop			146
#define KEY_pos			147
#define KEY_print		148
#define KEY_printf		149
#define KEY_prototype		150
#define KEY_push		151
#define KEY_q			152
#define KEY_qq			153
#define KEY_qr			154
#define KEY_quotemeta		155
#define KEY_qw			156
#define KEY_qx			157
#define KEY_rand		158
#define KEY_read		159
#define KEY_readdir		160
#define KEY_readline		161
#define KEY_readlink		162
#define KEY_readpipe		163
#define KEY_recv		164
#define KEY_redo		165
#define KEY_ref			166
#define KEY_rename		167
#define KEY_require		168
#define KEY_reset		169
#define KEY_return		170
#define KEY_reverse		171
#define KEY_rewinddir		172
#define KEY_rindex		173
#define KEY_rmdir		174
#define KEY_s			175
#define KEY_scalar		176
#define KEY_seek		177
#define KEY_seekdir		178
#define KEY_select		179
#define KEY_semctl		180
#define KEY_semget		181
#define KEY_semop		182
#define KEY_send		183
#define KEY_setgrent		184
#define KEY_sethostent		185
#define KEY_setnetent		186
#define KEY_setpgrp		187
#define KEY_setpriority		188
#define KEY_setprotoent		189
#define KEY_setpwent		190
#define KEY_setservent		191
#define KEY_setsockopt		192
#define KEY_shift		193
#define KEY_shmctl		194
#define KEY_shmget		195
#define KEY_shmread		196
#define KEY_shmwrite		197
#define KEY_shutdown		198
#define KEY_sin			199
#define KEY_sleep		200
#define KEY_socket		201
#define KEY_socketpair		202
#define KEY_sort		203
#define KEY_splice		204
#define KEY_split		205
#define KEY_sprintf		206
#define KEY_sqrt		207
#define KEY_srand		208
#define KEY_stat		209
#define KEY_study		210
#define KEY_sub			211
#define KEY_substr		212
#define KEY_symlink		213
#define KEY_syscall		214
#define KEY_sysopen		215
#define KEY_sysread		216
#define KEY_sysseek		217
#define KEY_system		218
#define KEY_syswrite		219
#define KEY_tell		220
#define KEY_telldir		221
#define KEY_tie			222
#define KEY_tied		223
#define KEY_time		224
#define KEY_times		225
#define KEY_tr			226
#define KEY_truncate		227
#define KEY_uc			228
#define KEY_ucfirst		229
#define KEY_umask		230
#define KEY_undef		231
#define KEY_unless		232
#define KEY_unlink		233
#define KEY_unpack		234
#define KEY_unshift		235
#define KEY_untie		236
#define KEY_until		237
#define KEY_use			238
#define KEY_utime		239
#define KEY_values		240
#define KEY_vec			241
#define KEY_wait		242
#define KEY_waitpid		243
#define KEY_wantarray		244
#define KEY_warn		245
#define KEY_while		246
#define KEY_write		247
#define KEY_x			248
#define KEY_xor			249
#define KEY_y			250
